[−][src]Crate syn_inline_mod
Utility to traverse the file-system and inline modules that are declared as references to other Rust files.
Structs
| InlinerBuilder | A builder that can configure how to inline modules. |
| SourceLocation | A source location |
Enums
| Error | An error that was encountered while inlining modules |
Functions
| parse_and_inline_modules | Parse the source code in |